import {
  globToRegExp
} from "./chunk-EGXUCKU4.js";
import {
  isHiddenPath
} from "./chunk-72CYVQ2Y.js";

// src/node/files.ts
import { readdirSync, statSync } from "node:fs";
import { join, resolve } from "node:path";
import process from "node:process";
function getStat(path) {
  try {
    return statSync(path);
  } catch (err) {
  }
}
function getFingerprint(path) {
  const { mtimeMs, size } = getStat(path) ?? {};
  return `${path}|${mtimeMs}|${size}`;
}
function walkSync(rootFolder, subFolder = "", ignoreHidden = true) {
  let resultPaths = [];
  const paths = readdirSync(resolve(rootFolder, subFolder));
  if (paths != null && paths.length > 0) {
    for (let file of paths) {
      file = join(subFolder, file);
      if (ignoreHidden && isHiddenPath(file))
        continue;
      const realFile = join(rootFolder, file);
      const stat = getStat(realFile);
      if (stat && stat.isDirectory())
        resultPaths = resultPaths.concat(walkSync(rootFolder, file) || []);
      else
        resultPaths.push(file);
    }
  }
  return resultPaths;
}
function files(opt = {}) {
  let {
    pattern,
    filter,
    basePath = process.cwd(),
    ignoreHidden = false
  } = opt;
  let paths = walkSync(basePath, "", ignoreHidden);
  paths = paths.filter(
    (path) => !(ignoreHidden && (path.startsWith(".") || path.includes("/.")))
  );
  if (pattern) {
    if (typeof pattern === "string")
      pattern = globToRegExp(pattern);
    if (pattern instanceof RegExp) {
      const rx = pattern;
      rx.lastIndex = 0;
      paths = paths.filter((path) => rx.test(path));
    }
  }
  if (filter)
    paths = paths.filter(filter);
  return paths;
}

export {
  getStat,
  getFingerprint,
  walkSync,
  files
};
//# sourceMappingURL=chunk-27E2KTZK.js.map