import {
  useDispose
} from "./chunk-KGD7JR27.js";
import {
  promisify
} from "./chunk-FSDCRQB3.js";

// src/common/dispose-utils.ts
function useTimeout(fn, timeout = 0) {
  let timeoutHandle = setTimeout(fn, timeout);
  return () => {
    if (timeoutHandle) {
      clearTimeout(timeoutHandle);
      timeoutHandle = void 0;
    }
  };
}
function useInterval(fn, interval) {
  let intervalHandle = setInterval(fn, interval);
  return () => {
    if (intervalHandle) {
      clearInterval(intervalHandle);
      intervalHandle = void 0;
    }
  };
}
function useIntervalPause(fn, interval, immediately = false) {
  let intervalHandle;
  let stop = false;
  async function loop(exec = false) {
    if (exec)
      await promisify(fn());
    if (!stop)
      intervalHandle = setTimeout(() => loop(true), interval);
  }
  void loop(immediately);
  return () => {
    if (intervalHandle) {
      stop = true;
      clearInterval(intervalHandle);
      intervalHandle = void 0;
    }
  };
}
function useEventListener(emitter, eventName, fn, ...args) {
  if (emitter == null)
    return () => {
    };
  if (emitter.on)
    emitter.on(eventName, fn, ...args);
  else if (emitter.addEventListener)
    emitter.addEventListener(eventName, fn, ...args);
  return () => {
    if (emitter.off)
      emitter.off(eventName, fn, ...args);
    else if (emitter.removeEventListener)
      emitter.removeEventListener(eventName, fn, ...args);
  };
}
function useEventListenerOnce(emitter, eventName, fn, ...args) {
  if (emitter == null)
    return () => {
    };
  if (emitter.on)
    emitter.once(eventName, fn, ...args);
  else if (emitter.addEventListener)
    emitter.addEventListener(eventName, fn, ...args);
  return () => {
    if (emitter.off)
      emitter.off(eventName, fn, ...args);
    else if (emitter.removeEventListener)
      emitter.removeEventListener(eventName, fn, ...args);
  };
}
function useDisposeWithUtils(config) {
  const dispose = useDispose(config);
  return Object.assign(dispose, {
    timeout: (fn, timeout = 0) => dispose.add(useTimeout(fn, timeout)),
    interval: (fn, interval = 0) => dispose.add(useInterval(fn, interval)),
    intervalPause: (fn, interval = 0) => dispose.add(useIntervalPause(fn, interval)),
    on: (emitter, eventName, fn, ...args) => dispose.add(useEventListener(emitter, eventName, fn, ...args)),
    once: (emitter, eventName, fn, ...args) => dispose.add(useEventListenerOnce(emitter, eventName, fn, ...args))
  });
}

export {
  useTimeout,
  useInterval,
  useIntervalPause,
  useEventListener,
  useEventListenerOnce,
  useDisposeWithUtils
};
//# sourceMappingURL=chunk-7CAGRWCE.js.map