import {
  DefaultLogger
} from "./chunk-VAS3X5GJ.js";
import {
  encodeQuery
} from "./chunk-5Y3HYG6B.js";
import {
  deepMerge
} from "./chunk-BCFBEP5B.js";
import {
  isArray
} from "./chunk-EOHXRMVQ.js";
import {
  arrayFlatten
} from "./chunk-AEBHR4XF.js";
import {
  toBase64
} from "./chunk-VVNSHVPQ.js";
import {
  jsonStringifySafe
} from "./chunk-6GHO7LQW.js";

// src/common/network.ts
var defaultOptions = {
  cache: "no-cache",
  redirect: "follow",
  headers: {}
};
function parseBasicAuth(url) {
  const m = /:\/\/([^@]*)@/gi.exec(url);
  if (m && m[1]) {
    const [username, password] = m[1].split(":", 2);
    return {
      url: url.replace(`${m[1]}@`, ""),
      username,
      password
    };
  }
}
async function fetchBasic(url, fetchOptions = {}, fetchFn = fetch) {
  try {
    if (isArray(fetchOptions))
      fetchOptions = deepMerge({}, ...arrayFlatten(fetchOptions));
    const auth = parseBasicAuth(String(url));
    if (auth) {
      url = auth.url;
      fetchOptions = deepMerge(
        {},
        fetchOptions,
        fetchOptionsBasicAuth(auth.username, auth.password)
      );
    }
    if (
      // @ts-expect-error headers
      fetchOptions.headers != null && !(fetchOptions.headers instanceof Headers)
    ) {
      fetchOptions.headers = new Headers(fetchOptions.headers);
    }
    const response = await fetchFn(String(url), fetchOptions);
    if (response.status < 400)
      return response;
    const log = DefaultLogger("zeed:network");
    try {
      log.warn(`Fetch of ${String(url)} returned status=${response.status}. Options:`, fetchOptions);
      log.warn(`Response: ${await response.text()}`);
    } catch (err) {
      log.error("Exception:", err);
    }
  } catch (err) {
    const log = DefaultLogger("zeed:network");
    log.error("fetchBasic", err);
  }
}
async function fetchJson(url, fetchOptions = {}, fetchFn = fetch) {
  try {
    const res = await fetchBasic(
      url,
      [
        {
          method: "GET",
          headers: {
            Accept: "application/json"
          }
        },
        fetchOptions
      ],
      fetchFn
    );
    if (res)
      return await res.json();
  } catch (err) {
    const log = DefaultLogger("zeed:network");
    log.error("fetchJSON error:", err);
  }
}
async function fetchText(url, fetchOptions = {}, fetchFn = fetch) {
  try {
    const res = await fetchBasic(
      url,
      [defaultOptions, { method: "GET" }, fetchOptions],
      fetchFn
    );
    if (res)
      return await res.text();
  } catch (err) {
    const log = DefaultLogger("zeed:network");
    log.error("fetchHTML error:", err);
  }
}
function fetchOptionsFormURLEncoded(data, method = "POST") {
  return {
    method,
    ...defaultOptions,
    headers: {
      "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
    },
    body: encodeQuery(data)
  };
}
function fetchOptionsJson(data, method = "POST") {
  return {
    method,
    ...defaultOptions,
    headers: {
      "Content-Type": "application/json; charset=utf-8"
      // Accept: "application/json",
    },
    body: jsonStringifySafe(data)
  };
}
function fetchOptionsBasicAuth(username, password) {
  return {
    headers: {
      Authorization: `Basic ${toBase64(`${username}:${password}`)}`
    }
  };
}

export {
  parseBasicAuth,
  fetchBasic,
  fetchJson,
  fetchText,
  fetchOptionsFormURLEncoded,
  fetchOptionsJson,
  fetchOptionsBasicAuth
};
//# sourceMappingURL=chunk-BJGZAXQX.js.map