import {
  browserSupportsColors
} from "./chunk-NJEREDIC.js";
import {
  browserSelectColorByName
} from "./chunk-I45WP5PM.js";
import {
  useLevelFilter,
  useNamespaceFilter
} from "./chunk-GUPXJFTH.js";
import {
  LogLevelError,
  LogLevelInfo,
  LogLevelWarn
} from "./chunk-WXJDMWFH.js";
import {
  formatMilliseconds,
  getTimestamp
} from "./chunk-NJF7RWE7.js";

// src/browser/log/log-browser.ts
function LoggerBrowserHandler(opt = {}) {
  const styleFont = 'font-family: "JetBrains Mono", Menlo; font-size: 11px;';
  const styleDefault = `${styleFont}`;
  const styleBold = `font-weight: 600; ${styleFont}`;
  const useColors = browserSupportsColors();
  const namespaces = {};
  const startTime = getTimestamp();
  const {
    filter = void 0,
    level = void 0,
    colors = true,
    // levelHelper = false,
    // nameBrackets = true,
    padding = 16,
    time = true
  } = opt;
  const matchesNamespace = useNamespaceFilter(filter);
  const matchesLevel = useLevelFilter(level);
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    const timeDiffString = time ? `+${formatMilliseconds(getTimestamp() - startTime)}` : "";
    let name = msg.name || "";
    let ninfo = namespaces[name || ""];
    if (ninfo == null) {
      ninfo = {
        color: browserSelectColorByName(name)
        // time: timeNow
      };
      namespaces[name] = ninfo;
    }
    let args;
    if (padding > 0)
      name = name.padEnd(16, " ");
    if (colors && useColors) {
      args = [`%c${name}%c 	%s %c${timeDiffString}`];
      args.push(`color:${ninfo.color}; ${styleBold}`);
      args.push(styleDefault);
      args.push(msg.messages?.[0] ?? "");
      args.push(`color:${ninfo.color};`);
      args.push(...msg.messages.slice(1));
    } else {
      args = [name, ...msg.messages, `+${timeDiffString}`];
    }
    args = args.map((arg) => {
      if (arg instanceof Uint8Array)
        return `<Uint8Array size=${arg.length}>`;
      return arg;
    });
    switch (msg.level) {
      case LogLevelInfo:
        if (opt.levelHelper)
          args[0] = `I|*   ${args[0]}`;
        console.info(...args);
        break;
      case LogLevelWarn:
        if (opt.levelHelper)
          args[0] = `W|**  ${args[0]}`;
        console.warn(...args);
        break;
      case LogLevelError:
        if (opt.levelHelper)
          args[0] = `E|*** ${args[0]}`;
        console.error(...args);
        break;
      default:
        if (opt.levelHelper)
          args[0] = `D|    ${args[0]}`;
        console.debug(...args);
        break;
    }
  };
}

export {
  LoggerBrowserHandler
};
//# sourceMappingURL=chunk-J2IAP56U.js.map