import {
  browserSupportsColors
} from "./chunk-NJEREDIC.js";
import {
  browserSelectColorByName
} from "./chunk-I45WP5PM.js";
import {
  parseLogLevel,
  useNamespaceFilter
} from "./chunk-GUPXJFTH.js";
import {
  LogLevelAll,
  LogLevelDebug,
  LogLevelError,
  LogLevelFatal,
  LogLevelInfo,
  LogLevelOff,
  LogLevelWarn
} from "./chunk-WXJDMWFH.js";

// src/browser/log/log-browser-factory.ts
function LoggerBrowserSetupDebugFactory(opt = {}) {
  const filter = opt.filter ?? localStorage.zeed ?? localStorage.debug;
  const styleFont = 'font-family: "JetBrains Mono", Menlo; font-size: 11px;';
  const styleDefault = `${styleFont}`;
  const styleBold = `font-weight: 600; ${styleFont}`;
  const useColors = browserSupportsColors();
  const noop = () => {
  };
  return function LoggerBrowserDebugFactory(name = "", logLevel) {
    let log;
    const matches = useNamespaceFilter(filter);
    const level = parseLogLevel(logLevel ?? LogLevelAll);
    if (matches(name) && level !== LogLevelOff) {
      let defineForLogLevel2 = function(fnLevel, fn) {
        if (level <= fnLevel)
          return fn;
        return () => {
        };
      };
      var defineForLogLevel = defineForLogLevel2;
      const fixedArgs = [];
      if (useColors) {
        const color = browserSelectColorByName(name);
        fixedArgs.push(`%c${name.padEnd(16, " ")}%c 	%s`);
        fixedArgs.push(`color:${color}; ${styleBold}`);
        fixedArgs.push(styleDefault);
      } else {
        fixedArgs.push(`[${name}] 	%s`);
      }
      log = defineForLogLevel2(LogLevelDebug, console.debug.bind(console, ...fixedArgs));
      log.debug = defineForLogLevel2(LogLevelDebug, console.debug.bind(console, ...fixedArgs));
      log.info = defineForLogLevel2(LogLevelInfo, console.info.bind(console, ...fixedArgs));
      log.warn = defineForLogLevel2(LogLevelWarn, console.warn.bind(console, ...fixedArgs));
      log.error = defineForLogLevel2(LogLevelError, console.error.bind(console, ...fixedArgs));
      log.fatal = defineForLogLevel2(LogLevelFatal, (...args) => {
        log.error(...args);
        throw new Error(`${args.map(String).join(" ")}`);
      });
      log.assert = defineForLogLevel2(LogLevelFatal, (condition, ...args) => {
        if (condition == null || typeof condition === "number" && Number.isNaN(condition) || !condition)
          log.fatal(...args);
      });
    } else {
      log = () => {
      };
      log.debug = noop;
      log.info = noop;
      log.warn = noop;
      log.error = noop;
      log.assert = noop;
      log.fatal = noop;
    }
    log.extend = (subName) => {
      return LoggerBrowserDebugFactory(name ? `${name}:${subName}` : subName);
    };
    log.label = name;
    return log;
  };
}
function activateConsoleDebug(_opt = {}) {
  console.info("activateConsoleDebug is activated by default in browsers");
}

export {
  LoggerBrowserSetupDebugFactory,
  activateConsoleDebug
};
//# sourceMappingURL=chunk-LWGUETUB.js.map