import { Encoder } from '../msg/encoder.cjs';
import { BinInput } from '../data/bin.cjs';

declare class BinaryEncoder implements Encoder {
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array | ArrayBuffer): Promise<any>;
}
/** Encode any object, including Uint8Array data */
declare function encodeJson(data: any): Uint8Array;
/** Decode any object, including Uint8Array data */
declare function decodeJson(data: Uint8Array | ArrayBuffer): any;
/** Incrementally encode binary data */
declare function createBinaryStreamEncoder(initialData?: BinInput): {
    /** Just writes the bytes. Length is not stored! */
    writeBytes: (data: BinInput, expectedLength: number) => void;
    writeBytesVar: (data: BinInput) => void;
    writeUintVar: (data: number) => void;
    writeUint8: (data: number) => void;
    writeUint16: (data: number) => void;
    writeUint32: (data: number) => void;
    writeIntVar: (data: number) => void;
    writeFloat: (data: number) => void;
    writeStringVar: (data: string) => void;
    write: (data: any) => void;
    getUint8Array: () => Uint8Array;
    getLength: () => number;
};
/** Incrementally decode binary data */
declare function createBinaryStreamDecoder(data: BinInput): {
    readBytes: (len: number) => Uint8Array;
    readBytesVar: () => Uint8Array;
    readUintVar: () => number;
    readUint8: () => number;
    readUint16: () => number;
    readUint32: () => number;
    readIntVar: () => number;
    readFloat: () => number;
    readStringVar: () => string;
    read: () => any;
    getOffset: () => number;
};
declare function bitfield(bitfield?: number): {
    setBit: (bit: number, value?: boolean) => number;
    unsetBit: (bit: number) => number;
    toggleBit: (bit: number) => number;
    getBit: (bit: number) => boolean;
    getValue: () => number;
};
declare function blobToArrayBuffer(blob: Blob | File): Promise<ArrayBuffer | undefined>;
declare function blobToUint8Array(blob: Blob | File): Promise<Uint8Array | undefined>;

export { BinaryEncoder, bitfield, blobToArrayBuffer, blobToUint8Array, createBinaryStreamDecoder, createBinaryStreamEncoder, decodeJson, encodeJson };
