import "../../chunk-HMRSQHLY.js";
import "../../chunk-UMUHNSGZ.js";
import "../../chunk-SRT6T6F5.js";
import {
  bitfield,
  createBinaryStreamDecoder,
  createBinaryStreamEncoder
} from "../../chunk-AWQDSHQ6.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-2PE4OYYB.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-264HKVNG.js";
import "../../chunk-BJGZAXQX.js";
import "../../chunk-YKE4UGGF.js";
import "../../chunk-FLFB2K34.js";
import "../../chunk-HST4VI64.js";
import "../../chunk-7CAGRWCE.js";
import "../../chunk-A7SUGWC3.js";
import "../../chunk-PXMCFDHI.js";
import "../../chunk-FG5BB5ND.js";
import "../../chunk-EW6FHLFK.js";
import "../../chunk-MPAXUMZ5.js";
import "../../chunk-MOF5RUYR.js";
import "../../chunk-Y24KGDZP.js";
import "../../chunk-7OAUULYN.js";
import "../../chunk-NZVHNXYU.js";
import "../../chunk-IQFZHKL7.js";
import "../../chunk-GJGVFPRX.js";
import "../../chunk-AJ3WFXQE.js";
import "../../chunk-3KZ4JGBB.js";
import "../../chunk-WO2K74GK.js";
import "../../chunk-PJDBG5VS.js";
import "../../chunk-H3BEMJTD.js";
import "../../chunk-ULLOUKBT.js";
import "../../chunk-KGD7JR27.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-CQWFE2OA.js";
import "../../chunk-VAS3X5GJ.js";
import "../../chunk-GAKRSKPV.js";
import "../../chunk-455C43FU.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-RG6OSZW5.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-GUPXJFTH.js";
import "../../chunk-WXJDMWFH.js";
import "../../chunk-NJF7RWE7.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-QKQXPWN7.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-BCFBEP5B.js";
import "../../chunk-EOHXRMVQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-66LHCCNT.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import {
  Uint8ArrayToHexDump,
  toHex
} from "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/bin/index.spec.ts
describe("encoder", () => {
  it("should write a stream", () => {
    const stream = createBinaryStreamEncoder();
    stream.writeUint32(1);
    stream.write({ a: "99" });
    stream.writeBytes([1, 2, 3], 3);
    stream.write(123);
    const bin = stream.getUint8Array();
    expect(Uint8ArrayToHexDump(bin)).toMatchInlineSnapshot(`
      "0000  01 00 00 00 76 01 01 61 77 02 39 39 01 02 03 7d  ....v..aw.99...}
      0010  bb 01                                            \xBB.              "
    `);
    expect(stream.getLength()).toBe(18);
    const readStream = createBinaryStreamDecoder(bin);
    expect(readStream.getOffset()).toBe(0);
    expect(readStream.readUint32()).toBe(1);
    expect(readStream.getOffset()).toBe(4);
    expect(readStream.read()).toEqual({ a: "99" });
    expect(readStream.readBytes(3)).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
    expect(readStream.read()).toBe(123);
    expect(readStream.getOffset()).toBe(bin.length);
  });
  it("should bitfield", () => {
    const bf = bitfield(1);
    bf.setBit(4);
    expect(bf.getValue()).toBe(17);
    bf.setBit(0, false);
    expect(bf.getValue()).toBe(16);
    bf.setBit(1);
    bf.setBit(5);
    bf.setBit(16);
    expect(bf.getValue().toString(2)).toMatchInlineSnapshot(
      '"10000000000110010"'
    );
    expect(bf.getValue()).toBe(65586);
    expect(bf.getBit(0)).toBe(false);
    expect(bf.getBit(4)).toBe(true);
    bf.toggleBit(4);
    expect(bf.getBit(4)).toBe(false);
    expect(bf.getValue()).toBe(65570);
  });
  it("should var bin", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeIntVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(128)).toMatchInlineSnapshot('"8002"');
    expect(enc(-1)).toMatchInlineSnapshot('"41"');
    expect(enc(-691529286)).toMatchInlineSnapshot('"c699bf9305"');
    expect(enc(691529286)).toMatchInlineSnapshot('"8699bf9305"');
  });
  it("should var bin uint", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeUintVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(127)).toMatchInlineSnapshot('"7f"');
    expect(enc(128)).toMatchInlineSnapshot(`"8001"`);
    expect(enc(255)).toMatchInlineSnapshot('"ff01"');
    expect(enc(256)).toMatchInlineSnapshot('"8002"');
    expect(enc(691529286)).toMatchInlineSnapshot('"c6ccdfc902"');
  });
});
//# sourceMappingURL=index.spec.js.map