"use strict";


var _chunkXDY4SRCLcjs = require('../../chunk-XDY4SRCL.cjs');
require('../../chunk-66YRDFQP.cjs');
require('../../chunk-7FPSHSSO.cjs');

// src/common/data/basex.spec.ts
describe("baseX", () => {
  it("should encode base16", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, 16);
    expect(encode([1, 9, 0, 255])).toBe("10900ff");
    expect(decode("00010900ff")).toEqual(new Uint8Array([1, 9, 0, 255]));
  });
  it("should encode base62", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, 62);
    expect(encode([0, 1, 9, 0, 255])).toBe("1As1f");
    expect(decode("01As1f")).toEqual(new Uint8Array([1, 9, 0, 255]));
  });
  it("should encode base62 carry", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, 62);
    expect(encode([61])).toBe("z");
    expect(encode([62])).toBe("10");
    expect(decode("z")).toEqual(new Uint8Array([61]));
    expect(decode("0z")).toEqual(new Uint8Array([61]));
    expect(decode("10")).toEqual(new Uint8Array([62]));
  });
  it("should encode suid length", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, 62);
    expect(
      encode([
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255
      ])
    ).toBe("7n42DGM5Tflk9n8mt7Fhc7");
    expect(decode("7n42DGM5Tflk9n8mt7Fhc7")).toEqual(
      new Uint8Array([
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255,
        255
      ])
    );
    expect(encode([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], 22)).toBe(
      "0000000000000000000001"
    );
    expect(decode("0000000000000000000001", 16)).toEqual(
      new Uint8Array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1])
    );
  });
  it("should encode arraybuffer", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, 62);
    const buf = Buffer.from([0, 1, 9, 0, 255]);
    expect(encode(buf)).toBe("1As1f");
    expect(decode("01As1f")).toEqual(new Uint8Array([1, 9, 0, 255]));
  });
  it("should estimate size", () => {
    expect(_chunkXDY4SRCLcjs.estimateSizeForBase.call(void 0, 16, 62)).toMatchInlineSnapshot("22");
    expect(_chunkXDY4SRCLcjs.estimateSizeForBase.call(void 0, 16, 64)).toMatchInlineSnapshot("22");
    expect(_chunkXDY4SRCLcjs.estimateSizeForBase.call(void 0, 16, 32)).toMatchInlineSnapshot("26");
    expect(_chunkXDY4SRCLcjs.estimateSizeForBase.call(void 0, 16, 16)).toMatchInlineSnapshot("32");
    expect(_chunkXDY4SRCLcjs.estimateSizeForBase.call(void 0, 159, 32)).toMatchInlineSnapshot("255");
    expect(_chunkXDY4SRCLcjs.estimateSizeForBase.call(void 0, 156, 32)).toMatchInlineSnapshot("250");
  });
  it("should support custom", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567");
    const buf = Buffer.from([0, 1, 9, 0, 255]);
    expect(encode(buf)).toBe("QSAH7");
    expect(decode("QSAH7")).toEqual(new Uint8Array([1, 9, 0, 255]));
  });
  it("should support 32-zbase", () => {
    const { encode, decode } = _chunkXDY4SRCLcjs.useBase.call(void 0, "32-zbase");
    const buf = Buffer.from([0, 1, 9, 0, 255]);
    expect(encode(buf)).toBe("o1y89");
    expect(decode("o1y89")).toEqual(new Uint8Array([1, 9, 0, 255]));
  });
});
//# sourceMappingURL=basex.spec.cjs.map