import "../../chunk-UHTVWILC.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-QKQXPWN7.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-BCFBEP5B.js";
import "../../chunk-EOHXRMVQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-66LHCCNT.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import {
  createArray
} from "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import {
  Uint8ArrayToHexDump,
  Uint8ArrayToJson,
  Uint8ArrayToString,
  equalBinary,
  fromBase64,
  fromBase64String,
  fromHex,
  joinToUint8Array,
  jsonToUint8Array,
  stringToUInt8Array,
  toBase64,
  toBase64Url,
  toHex,
  toUint8Array
} from "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/data/bin.spec.ts
describe("bin", () => {
  it("should compare", () => {
    const pingMessage = new Uint8Array([9]);
    const pongMessage = new Uint8Array([10]);
    expect(equalBinary(pingMessage, pongMessage)).toBe(false);
    expect(equalBinary(pingMessage, pingMessage)).toBe(true);
  });
  it("should text code", () => {
    const sample = "Hello \u2192 w\xF6rld \u{1F468}\u200D\u{1F469}\u200D\u{1F467}\u200D\u{1F466}.";
    const encoded = stringToUInt8Array(sample);
    expect(toBase64([1, 2, 3])).toEqual("AQID");
    expect(toHex([1, 2, 254, 255])).toEqual("0102feff");
    expect(fromHex("0102feff")).toMatchInlineSnapshot(`
      Uint8Array [
        1,
        2,
        254,
        255,
      ]
    `);
    expect(toBase64(encoded)).toEqual(
      "SGVsbG8g4oaSIHfDtnJsZCDwn5Go4oCN8J+RqeKAjfCfkafigI3wn5GmLg=="
    );
    expect(toBase64(encoded, true)).toEqual(
      "SGVsbG8g4oaSIHfDtnJsZCDwn5Go4oCN8J+RqeKAjfCfkafigI3wn5GmLg"
    );
    expect(toBase64Url(encoded)).toEqual(
      "SGVsbG8g4oaSIHfDtnJsZCDwn5Go4oCN8J-RqeKAjfCfkafigI3wn5GmLg"
    );
    expect(
      Uint8ArrayToString(
        fromBase64("SGVsbG8g4oaSIHfDtnJsZCDwn5Go4oCN8J-RqeKAjfCfkafigI3wn5GmLg")
      )
    ).toBe(sample);
    expect(
      fromBase64("SGVsbG8g4oaSIHfDtnJsZCDwn5Go4oCN8J+RqeKAjfCfkafigI3wn5Gm")
    ).toMatchInlineSnapshot(`
Uint8Array [
  72,
  101,
  108,
  108,
  111,
  32,
  226,
  134,
  146,
  32,
  119,
  195,
  182,
  114,
  108,
  100,
  32,
  240,
  159,
  145,
  168,
  226,
  128,
  141,
  240,
  159,
  145,
  169,
  226,
  128,
  141,
  240,
  159,
  145,
  167,
  226,
  128,
  141,
  240,
  159,
  145,
  166,
]
`);
    expect(Uint8ArrayToString(encoded)).toEqual(sample);
    expect(Uint8ArrayToString(encoded)).not.toEqual(`${sample}a`);
  });
  it("should encode JSON", () => {
    const sample = {
      name: "Hello \u2192 w\xF6rld \u{1F468}\u200D\u{1F469}\u200D\u{1F467}\u200D\u{1F466}",
      list: [1, false, "test"],
      num: 1
    };
    const bin = jsonToUint8Array(sample);
    expect(bin).toMatchInlineSnapshot(`
      Uint8Array [
        123,
        34,
        110,
        97,
        109,
        101,
        34,
        58,
        34,
        72,
        101,
        108,
        108,
        111,
        32,
        226,
        134,
        146,
        32,
        119,
        195,
        182,
        114,
        108,
        100,
        32,
        240,
        159,
        145,
        168,
        226,
        128,
        141,
        240,
        159,
        145,
        169,
        226,
        128,
        141,
        240,
        159,
        145,
        167,
        226,
        128,
        141,
        240,
        159,
        145,
        166,
        34,
        44,
        34,
        108,
        105,
        115,
        116,
        34,
        58,
        91,
        49,
        44,
        102,
        97,
        108,
        115,
        101,
        44,
        34,
        116,
        101,
        115,
        116,
        34,
        93,
        44,
        34,
        110,
        117,
        109,
        34,
        58,
        49,
        125,
      ]
    `);
    const back = Uint8ArrayToJson(bin);
    expect(back).toEqual(sample);
  });
  it("should inline string conversions", () => {
    expect(toUint8Array("abc")).toMatchInlineSnapshot(`
Uint8Array [
  97,
  98,
  99,
]
`);
    expect(new Uint8Array([1, 2, 3])).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
  });
  it("should toUint8Array", () => {
    expect(toUint8Array(Buffer.from("abc"))).toMatchInlineSnapshot(`
Uint8Array [
  97,
  98,
  99,
]
`);
    expect(toUint8Array("abc")).toMatchInlineSnapshot(`
Uint8Array [
  97,
  98,
  99,
]
`);
    expect(toUint8Array([1, 2, 3])).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
  });
  it("should join bins", () => {
    const result = joinToUint8Array([new Uint8Array([1, 2, 3]), "abc"]);
    expect(result).toMatchInlineSnapshot(`
      Uint8Array [
        1,
        2,
        3,
        97,
        98,
        99,
      ]
    `);
    const result2 = joinToUint8Array(new Uint8Array([1, 2, 3]), "abc");
    expect(result2).toMatchInlineSnapshot(`
      Uint8Array [
        1,
        2,
        3,
        97,
        98,
        99,
      ]
    `);
  });
  it("should dump", () => {
    const values = createArray(256, (i) => i);
    const data = new Uint8Array(values);
    const hex = Uint8ArrayToHexDump(data);
    expect(hex).toMatchInlineSnapshot(`
      "0000  00 01 02 03 04 05 06 07 08 09 0a 0b 0c 0d 0e 0f  ................
      0010  10 11 12 13 14 15 16 17 18 19 1a 1b 1c 1d 1e 1f  ................
      0020  20 21 22 23 24 25 26 27 28 29 2a 2b 2c 2d 2e 2f  .!"#$%&'()*+,-./
      0030  30 31 32 33 34 35 36 37 38 39 3a 3b 3c 3d 3e 3f  0123456789:;<=>?
      0040  40 41 42 43 44 45 46 47 48 49 4a 4b 4c 4d 4e 4f  @ABCDEFGHIJKLMNO
      0050  50 51 52 53 54 55 56 57 58 59 5a 5b 5c 5d 5e 5f  PQRSTUVWXYZ[\\]^_
      0060  60 61 62 63 64 65 66 67 68 69 6a 6b 6c 6d 6e 6f  \`abcdefghijklmno
      0070  70 71 72 73 74 75 76 77 78 79 7a 7b 7c 7d 7e 7f  pqrstuvwxyz{|}~.
      0080  80 81 82 83 84 85 86 87 88 89 8a 8b 8c 8d 8e 8f  ................
      0090  90 91 92 93 94 95 96 97 98 99 9a 9b 9c 9d 9e 9f  ................
      00a0  a0 a1 a2 a3 a4 a5 a6 a7 a8 a9 aa ab ac ad ae af  .\xA1\xA2\xA3\xA4\xA5\xA6\xA7\xA8\xA9\xAA\xAB\xAC.\xAE\xAF
      00b0  b0 b1 b2 b3 b4 b5 b6 b7 b8 b9 ba bb bc bd be bf  \xB0\xB1\xB2\xB3\xB4\xB5\xB6\xB7\xB8\xB9\xBA\xBB\xBC\xBD\xBE\xBF
      00c0  c0 c1 c2 c3 c4 c5 c6 c7 c8 c9 ca cb cc cd ce cf  \xC0\xC1\xC2\xC3\xC4\xC5\xC6\xC7\xC8\xC9\xCA\xCB\xCC\xCD\xCE\xCF
      00d0  d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 da db dc dd de df  \xD0\xD1\xD2\xD3\xD4\xD5\xD6\xD7\xD8\xD9\xDA\xDB\xDC\xDD\xDE\xDF
      00e0  e0 e1 e2 e3 e4 e5 e6 e7 e8 e9 ea eb ec ed ee ef  \xE0\xE1\xE2\xE3\xE4\xE5\xE6\xE7\xE8\xE9\xEA\xEB\xEC\xED\xEE\xEF
      00f0  f0 f1 f2 f3 f4 f5 f6 f7 f8 f9 fa fb fc fd fe ff  \xF0\xF1\xF2\xF3\xF4\xF5\xF6\xF7\xF8\xF9\xFA\xFB\xFC\xFD\xFE\xFF"
    `);
  });
  it("should base64Url", () => {
    const email = "example123+my@example.com";
    const b64 = toBase64Url(email);
    expect(b64).toMatchInlineSnapshot('"ZXhhbXBsZTEyMytteUBleGFtcGxlLmNvbQ"');
    const dec = fromBase64String(b64);
    expect(dec).toEqual(email);
  });
});
//# sourceMappingURL=bin.spec.js.map