"use strict";











var _chunkPOMZSIODcjs = require('../../chunk-POMZSIOD.cjs');
require('../../chunk-QU2LM4AI.cjs');
require('../../chunk-7FPSHSSO.cjs');

// src/common/data/is.spec.ts
describe("is", () => {
  it("should identify Uint8Array", () => {
    expect(_chunkPOMZSIODcjs.isUint8Array.call(void 0, new Uint8Array([1, 2, 3]))).toBe(true);
    expect(_chunkPOMZSIODcjs.isUint8Array.call(void 0, new Uint16Array([1, 2, 3]))).toBe(false);
    expect(_chunkPOMZSIODcjs.isUint8Array.call(void 0, {})).toBe(false);
    expect(_chunkPOMZSIODcjs.isUint8Array.call(void 0, [1, 2, 3])).toBe(false);
  });
  it("should identify object correctly", () => {
    class X {
      foo() {
        return "bar";
      }
    }
    const x = new X();
    const plain = { hello: "world" };
    function fn() {
      return "hello";
    }
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, X)).toBe(false);
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, x)).toBe(true);
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, plain)).toBe(true);
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, [])).toBe(true);
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, 123)).toBe(false);
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, /* @__PURE__ */ new Date())).toBe(true);
    expect(_chunkPOMZSIODcjs.isObject.call(void 0, fn)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, X)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, x)).toBe(true);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, plain)).toBe(true);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, [])).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, 123)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, /* @__PURE__ */ new Date())).toBe(true);
    expect(_chunkPOMZSIODcjs.isRecord.call(void 0, fn)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, X)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, x)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, plain)).toBe(true);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, [])).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, 123)).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, /* @__PURE__ */ new Date())).toBe(false);
    expect(_chunkPOMZSIODcjs.isRecordPlain.call(void 0, fn)).toBe(false);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, X)).toBe(false);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, x)).toBe(false);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, plain)).toBe(false);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, [])).toBe(false);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, 123)).toBe(true);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, /* @__PURE__ */ new Date())).toBe(false);
    expect(_chunkPOMZSIODcjs.isPrimitive.call(void 0, fn)).toBe(false);
  });
  it("should filter", async () => {
    const test = ["a", null, void 0, "b", false, "c", true, "", [], [1, 2, 3], {}, { a: 1 }];
    const r = test.filter(_chunkPOMZSIODcjs.isNotNull);
    expect(r).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        false,
        "c",
        true,
        "",
        Array [],
        Array [
          1,
          2,
          3,
        ],
        Object {},
        Object {
          "a": 1,
        },
      ]
    `);
    const rr = test.filter(_chunkPOMZSIODcjs.isValue);
    expect(rr).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        "c",
        "",
        Array [],
        Array [
          1,
          2,
          3,
        ],
        Object {},
        Object {
          "a": 1,
        },
      ]
    `);
    const rrr = test.filter(_chunkPOMZSIODcjs.isNotEmpty);
    expect(rrr).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        false,
        "c",
        true,
        Array [
          1,
          2,
          3,
        ],
        Object {
          "a": 1,
        },
      ]
    `);
    const rrrr = test.filter(_chunkPOMZSIODcjs.isEmpty);
    expect(rrrr).toMatchInlineSnapshot(`
      Array [
        null,
        undefined,
        "",
        Array [],
        Object {},
      ]
    `);
    const rrrrr = test.filter(_chunkPOMZSIODcjs.isTruthy);
    expect(rrrrr).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        "c",
        true,
        Array [],
        Array [
          1,
          2,
          3,
        ],
        Object {},
        Object {
          "a": 1,
        },
      ]
    `);
  });
  it("should handle NaN", () => {
    const nan = +"abc";
    expect(Number.isNaN(nan)).toBe(true);
    expect(typeof nan === "number").toBe(true);
    expect(_chunkPOMZSIODcjs.isNumber.call(void 0, nan)).toBe(false);
  });
});
//# sourceMappingURL=is.spec.cjs.map