import {
  isEmpty,
  isNotEmpty,
  isNotNull,
  isNumber,
  isObject,
  isPrimitive,
  isRecord,
  isRecordPlain,
  isTruthy,
  isUint8Array,
  isValue
} from "../../chunk-EOHXRMVQ.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-6GHO7LQW.js";

// src/common/data/is.spec.ts
describe("is", () => {
  it("should identify Uint8Array", () => {
    expect(isUint8Array(new Uint8Array([1, 2, 3]))).toBe(true);
    expect(isUint8Array(new Uint16Array([1, 2, 3]))).toBe(false);
    expect(isUint8Array({})).toBe(false);
    expect(isUint8Array([1, 2, 3])).toBe(false);
  });
  it("should identify object correctly", () => {
    class X {
      foo() {
        return "bar";
      }
    }
    const x = new X();
    const plain = { hello: "world" };
    function fn() {
      return "hello";
    }
    expect(isObject(X)).toBe(false);
    expect(isObject(x)).toBe(true);
    expect(isObject(plain)).toBe(true);
    expect(isObject([])).toBe(true);
    expect(isObject(123)).toBe(false);
    expect(isObject(/* @__PURE__ */ new Date())).toBe(true);
    expect(isObject(fn)).toBe(false);
    expect(isRecord(X)).toBe(false);
    expect(isRecord(x)).toBe(true);
    expect(isRecord(plain)).toBe(true);
    expect(isRecord([])).toBe(false);
    expect(isRecord(123)).toBe(false);
    expect(isRecord(/* @__PURE__ */ new Date())).toBe(true);
    expect(isRecord(fn)).toBe(false);
    expect(isRecordPlain(X)).toBe(false);
    expect(isRecordPlain(x)).toBe(false);
    expect(isRecordPlain(plain)).toBe(true);
    expect(isRecordPlain([])).toBe(false);
    expect(isRecordPlain(123)).toBe(false);
    expect(isRecordPlain(/* @__PURE__ */ new Date())).toBe(false);
    expect(isRecordPlain(fn)).toBe(false);
    expect(isPrimitive(X)).toBe(false);
    expect(isPrimitive(x)).toBe(false);
    expect(isPrimitive(plain)).toBe(false);
    expect(isPrimitive([])).toBe(false);
    expect(isPrimitive(123)).toBe(true);
    expect(isPrimitive(/* @__PURE__ */ new Date())).toBe(false);
    expect(isPrimitive(fn)).toBe(false);
  });
  it("should filter", async () => {
    const test = ["a", null, void 0, "b", false, "c", true, "", [], [1, 2, 3], {}, { a: 1 }];
    const r = test.filter(isNotNull);
    expect(r).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        false,
        "c",
        true,
        "",
        Array [],
        Array [
          1,
          2,
          3,
        ],
        Object {},
        Object {
          "a": 1,
        },
      ]
    `);
    const rr = test.filter(isValue);
    expect(rr).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        "c",
        "",
        Array [],
        Array [
          1,
          2,
          3,
        ],
        Object {},
        Object {
          "a": 1,
        },
      ]
    `);
    const rrr = test.filter(isNotEmpty);
    expect(rrr).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        false,
        "c",
        true,
        Array [
          1,
          2,
          3,
        ],
        Object {
          "a": 1,
        },
      ]
    `);
    const rrrr = test.filter(isEmpty);
    expect(rrrr).toMatchInlineSnapshot(`
      Array [
        null,
        undefined,
        "",
        Array [],
        Object {},
      ]
    `);
    const rrrrr = test.filter(isTruthy);
    expect(rrrrr).toMatchInlineSnapshot(`
      Array [
        "a",
        "b",
        "c",
        true,
        Array [],
        Array [
          1,
          2,
          3,
        ],
        Object {},
        Object {
          "a": 1,
        },
      ]
    `);
  });
  it("should handle NaN", () => {
    const nan = +"abc";
    expect(Number.isNaN(nan)).toBe(true);
    expect(typeof nan === "number").toBe(true);
    expect(isNumber(nan)).toBe(false);
  });
});
//# sourceMappingURL=is.spec.js.map