import {
  Emitter
} from "../../chunk-H3BEMJTD.js";
import {
  useDispose
} from "../../chunk-KGD7JR27.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-CQWFE2OA.js";
import "../../chunk-VAS3X5GJ.js";
import "../../chunk-GAKRSKPV.js";
import "../../chunk-455C43FU.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-GUPXJFTH.js";
import "../../chunk-WXJDMWFH.js";
import "../../chunk-NJF7RWE7.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-T7PU5CTZ.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-X2DIUKLP.js";
import "../../chunk-2HWPZ6ZE.js";
import {
  objectInclusivePick,
  objectMap,
  objectMergeDisposable,
  objectOmit,
  objectPick,
  objectPlain
} from "../../chunk-QKQXPWN7.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-BCFBEP5B.js";
import "../../chunk-EOHXRMVQ.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-66LHCCNT.js";
import "../../chunk-4XPO57AQ.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import "../../chunk-NS4INNCL.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-R6KULE2F.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-VVNSHVPQ.js";
import "../../chunk-6GHO7LQW.js";

// src/common/data/object.spec.ts
describe("object.spec", () => {
  it("should map it", async () => {
    const sample = {
      a: 1,
      b: 2
    };
    expect(objectMap(sample, (k, v) => v + 10)).toMatchInlineSnapshot(`
      Object {
        "a": 11,
        "b": 12,
      }
    `);
    expect(objectMap(sample, (k, v) => [`${k}_${v}`, k])).toMatchInlineSnapshot(`
        Object {
          "a_1": "a",
          "b_2": "b",
        }
      `);
  });
  it("should merge", async () => {
    const emitter = new Emitter();
    const obj = {
      dispose: useDispose(),
      f() {
        return 42;
      }
    };
    let x = 1;
    obj.dispose.add(() => x++);
    const m = objectMergeDisposable(emitter, obj);
    expect(m.f()).toBe(42);
    m.on("a", () => x++);
    void m.emit("a");
    expect(x).toBe(2);
    await m.dispose();
    expect(x).toBe(3);
  });
  it("should omit and pick", () => {
    const o = { a: 1, b: 2, c: 3, d: 4 };
    expect(objectPick(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
      }
    `);
    expect(objectOmit(o, "a", "c")).toMatchInlineSnapshot(`
      Object {
        "b": 2,
        "d": 4,
      }
    `);
    expect(objectInclusivePick(o, "a", "c", "x")).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "c": 3,
        "x": undefined,
      }
    `);
  });
});
describe("objectPlain", () => {
  it("should return the plain object", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: [3, 4]
      }
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle circular references", () => {
    const obj = {
      a: 1
    };
    obj.b = obj;
    const result = objectPlain(obj, { circleValue: "*** CIRCULAR ***" });
    expect(result).toMatchInlineSnapshot(`
      Object {
        "a": 1,
        "b": "*** CIRCULAR ***",
      }
    `);
  });
  it("should handle nested objects", () => {
    const obj = {
      a: 1,
      b: {
        c: 2,
        d: {
          e: 3
        }
      }
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle arrays", () => {
    const obj = {
      a: 1,
      b: [2, 3, 4]
    };
    const result = objectPlain(obj);
    expect(result).toEqual(obj);
  });
  it("should handle max depth", () => {
    const obj = {
      a: {
        b: {
          c: {
            d: {
              e: 1
            }
          }
        }
      }
    };
    const result = objectPlain(obj, { maxDepth: 3, maxDepthValue: "*** MAX DEPTH ***" });
    expect(result).toEqual({
      a: {
        b: {
          c: {
            d: "*** MAX DEPTH ***"
          }
        }
      }
    });
  });
  it("should handle removeUndefined", () => {
    const obj = {
      a: 1,
      b: void 0,
      c: [1, void 0]
    };
    const result = objectPlain(obj, { removeUndefined: true });
    expect(result).toEqual({ a: 1, c: [1] });
  });
});
//# sourceMappingURL=object.spec.js.map