import {
  endSortWeight,
  moveSortWeight,
  sortedItems,
  startSortWeight
} from "../../chunk-X2DIUKLP.js";
import {
  arrayShuffleForce,
  arrayShuffleInPlace
} from "../../chunk-AEBHR4XF.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-GY34N3KU.js";
import {
  last
} from "../../chunk-R6KULE2F.js";
import "../../chunk-6GHO7LQW.js";

// src/common/data/sortable.spec.ts
describe("sortable", () => {
  const list = [-0.2, -1e-3, 0, 1e-3, 2];
  const items = list.map((sort_weight, index) => ({ index, sort_weight }));
  it("should add correctly", () => {
    expect(startSortWeight(items)).toBeLessThan(list[0]);
    expect(endSortWeight(items)).toBeGreaterThan(last(list) || 0);
  });
  it("should sort correctly", () => {
    const shuffledItems = arrayShuffleForce(items);
    expect(shuffledItems.map((el) => el.sort_weight)).not.toEqual(list);
    expect(sortedItems(shuffledItems).map((el) => el.sort_weight)).toEqual(list);
  });
  it("should move correctly", () => {
    let items2 = [];
    for (let i = 0; i < 10; i++) {
      items2.push({
        name: String(i),
        sort_weight: i
      });
    }
    expect(
      sortedItems(items2).map((o) => o.name).join("")
    ).toEqual("0123456789");
    const moveItem = items2[8];
    moveItem.sort_weight = moveSortWeight(1, 8, items2);
    expect(
      sortedItems(items2).map((o) => o.name).join("")
    ).toEqual("0812345679");
    items2 = sortedItems(items2);
    const moveItem2 = items2[1];
    arrayShuffleInPlace(items2);
    moveItem2.sort_weight = moveSortWeight(8, 1, items2);
    expect(
      sortedItems(items2).map((o) => o.name).join("")
    ).toEqual("0123456789");
  });
});
//# sourceMappingURL=sortable.spec.js.map