import {
  useDisposeWithUtils,
  useEventListener,
  useTimeout
} from "../chunk-7CAGRWCE.js";
import "../chunk-EW6FHLFK.js";
import "../chunk-MPAXUMZ5.js";
import "../chunk-MOF5RUYR.js";
import "../chunk-Y24KGDZP.js";
import "../chunk-7OAUULYN.js";
import "../chunk-NZVHNXYU.js";
import "../chunk-IQFZHKL7.js";
import "../chunk-GJGVFPRX.js";
import "../chunk-AJ3WFXQE.js";
import "../chunk-3KZ4JGBB.js";
import "../chunk-WO2K74GK.js";
import "../chunk-PJDBG5VS.js";
import "../chunk-H3BEMJTD.js";
import "../chunk-ULLOUKBT.js";
import "../chunk-KGD7JR27.js";
import "../chunk-7GOLOL5D.js";
import "../chunk-CQWFE2OA.js";
import "../chunk-VAS3X5GJ.js";
import "../chunk-GAKRSKPV.js";
import "../chunk-455C43FU.js";
import "../chunk-CFICINSP.js";
import "../chunk-RG6OSZW5.js";
import "../chunk-I45WP5PM.js";
import "../chunk-GUPXJFTH.js";
import "../chunk-WXJDMWFH.js";
import "../chunk-NJF7RWE7.js";
import "../chunk-UHTVWILC.js";
import "../chunk-T7PU5CTZ.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-AFUVZLZZ.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-QKQXPWN7.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-BCFBEP5B.js";
import "../chunk-EOHXRMVQ.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-66LHCCNT.js";
import "../chunk-4XPO57AQ.js";
import "../chunk-ACZDEHYB.js";
import "../chunk-FSDCRQB3.js";
import "../chunk-YEEGQOIW.js";
import "../chunk-AEBHR4XF.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-GY34N3KU.js";
import "../chunk-NS4INNCL.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-R6KULE2F.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-VVNSHVPQ.js";
import "../chunk-6GHO7LQW.js";

// src/common/dispose-utils.spec.ts
import { vi as jest } from "vitest";
describe("useTimeout", () => {
  it("should call the provided function after the specified timeout", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should cancel the timeout when the disposer function is called", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const disposer = useTimeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    disposer();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).not.toBeCalled();
  });
  it('should add event listener using "on" method if available', () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    disposer();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener using "addEventListener" method if "on" method is not available', () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    disposer();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const disposer = useEventListener(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
  it("should add timeout disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const timeout = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.timeout(mockFn, timeout);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(timeout);
    expect(mockFn).toBeCalled();
  });
  it("should add interval disposer to the dispose object", () => {
    jest.useFakeTimers();
    const mockFn = jest.fn();
    const interval = 1e3;
    const dispose = useDisposeWithUtils();
    dispose.interval(mockFn, interval);
    expect(mockFn).not.toBeCalled();
    jest.advanceTimersByTime(interval);
    expect(mockFn).toBeCalled();
  });
  it('should add event listener disposer to the dispose object using "on" method', async () => {
    const emitter = {
      on: jest.fn(),
      off: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.on).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.off).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.off).toBeCalledWith(eventName, fn, ...args);
  });
  it('should add event listener disposer to the dispose object using "addEventListener" method', async () => {
    const emitter = {
      addEventListener: jest.fn(),
      removeEventListener: jest.fn()
    };
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    dispose.on(emitter, eventName, fn, ...args);
    expect(emitter.addEventListener).toBeCalledWith(eventName, fn, ...args);
    expect(emitter.removeEventListener).not.toBeCalled();
    await dispose.dispose();
    expect(emitter.removeEventListener).toBeCalledWith(eventName, fn, ...args);
  });
  it("should return an empty disposer function if emitter is null 2", () => {
    const emitter = null;
    const eventName = "click";
    const fn = jest.fn();
    const args = [1, 2, 3];
    const dispose = useDisposeWithUtils();
    const disposer = dispose.on(emitter, eventName, fn, ...args);
    expect(disposer).toEqual(expect.any(Function));
    disposer();
  });
});
//# sourceMappingURL=dispose-utils.spec.js.map