import { Disposer, DisposerFunction } from '../dispose-types.js';
import { Progress } from './progress.js';
import { Emitter } from '../msg/emitter.js';
import '../global.js';
import '../log/log.js';
import '../log/log-base.js';

type PoolTaskIdConflictResolution = 'replace' | 'memoize' | 'prioritize' | 'error';
interface PoolConfig {
    name?: string;
    maxParallel?: number;
    idConflictResolution?: PoolTaskIdConflictResolution;
}
type PoolTaskFn<T = any> = (taskInfo: PoolTask<T>) => Promise<T>;
type PoolTaskState = 'waiting' | 'running' | 'finished';
/** Task */
interface PoolTask<T> {
    readonly id: string;
    readonly task: PoolTaskFn<T>;
    readonly done: (result?: any) => void;
    readonly setMax: (max: number) => void;
    readonly setResolved: (resolved: number) => void;
    readonly incResolved: (inc?: number) => void;
    state: PoolTaskState;
    priority: number;
    /** Same groups are executed only one at a time */
    group?: string;
    progress: Progress;
    max: number;
    resolved: number;
    result?: T;
    payload?: unknown;
}
interface PoolTaskEvents {
    didUpdate: (max: number, resolved: number, presentMax: number, presentResolved: number) => void;
    didStart: (id: string) => void;
    didCancel: (id: string) => void;
    didFinish: () => void;
    didResolve: (id: string, value: any) => void;
    didReject: (id: string, error: any) => void;
}
declare function usePool<T = any>(config?: PoolConfig): {
    events: Emitter<PoolTaskEvents, PoolTaskEvents>;
    cancel: (id: string) => void;
    cancelAll: () => void;
    hasById: (id: string) => boolean;
    progress: Progress;
    enqueue: <P>(task: PoolTaskFn<T>, config?: {
        id?: string | undefined;
        max?: number | undefined;
        resolved?: number | undefined;
        group?: string | undefined;
        idConflictResolution?: PoolTaskIdConflictResolution | undefined;
        payload?: P | undefined;
    }) => {
        id: string;
        promise: Promise<any>;
        dispose: () => void;
        cancel: () => void;
    };
    dispose: ((strictSync?: boolean) => void | Promise<any>) & {
        disposed: number;
        add: (obj?: Disposer | undefined) => DisposerFunction | undefined;
        remove: (disposable: Disposer) => void | Promise<void>;
        track: (obj?: Disposer | undefined) => DisposerFunction | undefined;
        untrack: (disposable: Disposer) => void | Promise<void>;
        dispose: (strictSync?: boolean) => void | Promise<any>;
        disposeSync: () => void;
        sync: () => void;
        exec: (strictSync?: boolean) => void | Promise<any>;
        getSize(): number;
        isDisposed(): boolean;
    };
    waitFinishAll: () => Promise<unknown>;
};

export { type PoolConfig, type PoolTask, type PoolTaskEvents, type PoolTaskFn, type PoolTaskIdConflictResolution, type PoolTaskState, usePool };
