"use strict";

var _chunkRJM35BFGcjs = require('../../chunk-RJM35BFG.cjs');
require('../../chunk-BKBCRA55.cjs');
require('../../chunk-37DK2SKC.cjs');
require('../../chunk-JSBFJVKM.cjs');
require('../../chunk-CXBBK7CI.cjs');
require('../../chunk-R7WMTFSS.cjs');
require('../../chunk-DRTH56G4.cjs');
require('../../chunk-XWE2OTGL.cjs');
require('../../chunk-KTC5RW57.cjs');
require('../../chunk-A4VFMLAN.cjs');
require('../../chunk-7XAMJGPO.cjs');
require('../../chunk-RKOTNV3K.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-UYIEHLQK.cjs');
require('../../chunk-N7OUNPMM.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-AZ5FKZIK.cjs');
require('../../chunk-POMZSIOD.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-XO4K2T3A.cjs');
require('../../chunk-3SM3C7HY.cjs');
require('../../chunk-UXNJ5WZM.cjs');
require('../../chunk-QYCE2TUJ.cjs');
require('../../chunk-ANZPWIO4.cjs');
require('../../chunk-CEXYDYSH.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-6T6PI6XG.cjs');
require('../../chunk-XDY4SRCL.cjs');
require('../../chunk-FYLSPYV2.cjs');
require('../../chunk-YKRFYR2Q.cjs');
require('../../chunk-QU2LM4AI.cjs');
require('../../chunk-BMRI2X66.cjs');
require('../../chunk-66YRDFQP.cjs');
require('../../chunk-7FPSHSSO.cjs');

// src/common/log/log.spec.ts
describe("logger", () => {
  it("should log different levels", () => {
    const messages = [];
    const logger = _chunkRJM35BFGcjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    log("Simple");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["Simple"],
        name: "test"
      },
      {
        level: 0,
        messages: ["Hello"],
        name: "test"
      },
      {
        level: 1,
        messages: ["World"],
        name: "test"
      },
      {
        level: 2,
        messages: ["is on"],
        name: "test"
      },
      {
        level: 3,
        messages: ["Fire"],
        name: "test"
      },
      {
        level: 4,
        messages: ["Fatal"],
        name: "test"
      }
    ]);
  });
  it("should log filter level", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkRJM35BFGcjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    expect(log.label).toBe("test");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      { name: "test", messages: ["Hello"], level: 0 },
      // xxx
      { name: "test", messages: ["World"], level: 1 },
      { name: "test", messages: ["is on"], level: 2 },
      { name: "test", messages: ["Fire"], level: 3 },
      { name: "test", messages: ["Fatal"], level: 4 }
    ]);
    {
      const log2 = log.extend("ext");
      log2.debug("Hello");
      log2.info("World2");
      log2.warn("is on");
      log2.error("Fire");
      try {
        log2.assert(false, "Fatal");
      } catch (err) {
      }
      expect(messages).toEqual([
        { name: "test", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test", messages: ["World"], level: 1 },
        { name: "test", messages: ["is on"], level: 2 },
        { name: "test", messages: ["Fire"], level: 3 },
        { name: "test", messages: ["Fatal"], level: 4 },
        { name: "test:ext", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test:ext", messages: ["World2"], level: 1 },
        { name: "test:ext", messages: ["is on"], level: 2 },
        { name: "test:ext", messages: ["Fire"], level: 3 },
        { name: "test:ext", messages: ["Fatal"], level: 4 }
      ]);
    }
  });
  it("should log filter namespace", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkRJM35BFGcjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    logger.setFilter("a*,-ab");
    const aa = logger("aa");
    const ab = logger("ab");
    const xy = logger("xy");
    aa("aa");
    ab("ab");
    xy("xy");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      }
    ]);
    const xyz = aa.extend("xyz");
    xyz("xyz");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      },
      {
        level: 0,
        messages: ["xyz"],
        name: "aa:xyz"
      }
    ]);
  });
  it("should fake log", () => {
    const messages = [];
    const logger = _chunkRJM35BFGcjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test", false);
    const { info, error, warn, debug, assert } = log;
    log("Simple");
    debug("Hello");
    info("World");
    warn("is on");
    error("Fire");
    expect(messages).toEqual([]);
  });
});
//# sourceMappingURL=log.spec.cjs.map