import '../log/log.js';
import { LoggerInterface } from '../log/log-base.js';
import { DisposerFunction } from '../dispose-types.js';

type EmitterHandler = (...objs: any[]) => void;
type EmitterAllHandler<T = string> = (key: T, ...objs: any[]) => void;
declare type ListenerSignature<L> = {
    [E in keyof L]: (...args: any[]) => any;
};
declare interface DefaultListener {
    [k: string]: (...args: any[]) => any;
}
interface EmitterSubscriberOptions {
    priority?: number;
}
declare class Emitter<RemoteListener extends ListenerSignature<RemoteListener> = DefaultListener, LocalListener extends ListenerSignature<LocalListener> = RemoteListener> {
    private subscribers;
    private subscribersOnAny;
    _logEmitter: LoggerInterface;
    /** RPC like emitting of events. */
    call: RemoteListener;
    /**
     * Emits an event to all subscribers and executes their corresponding event handlers.
     *
     * @param event - The event to emit.
     * @param args - The arguments to pass to the event handlers.
     * @returns A promise that resolves to a boolean indicating whether the event was successfully emitted.
     */
    emit<U extends keyof RemoteListener>(event: U, ...args: Parameters<RemoteListener[U]>): Promise<boolean>;
    onAny(fn: EmitterHandler): void;
    on<U extends keyof LocalListener>(event: U, fn: LocalListener[U], opt?: EmitterSubscriberOptions): DisposerFunction;
    onCall(handlers: Partial<LocalListener>): void;
    once<U extends keyof LocalListener>(event: U, listener: LocalListener[U]): DisposerFunction;
    off<U extends keyof LocalListener>(event: U, listener: LocalListener[U]): this;
    removeAllListeners(): this;
}
declare global {
    interface ZeedGlobalContext {
        emitter?: Emitter;
    }
    interface ZeedGlobalEmitter {
    }
}
/** Global emitter that will listen even across modules */
declare function getGlobalEmitter<T extends ListenerSignature<T> = ZeedGlobalEmitter>(): Emitter<T>;

export { type DefaultListener, Emitter, type EmitterAllHandler, type EmitterHandler, type EmitterSubscriberOptions, type ListenerSignature, getGlobalEmitter };
