import { LogLevelAliasType } from '../log/log-base.cjs';
import { Json } from '../types.cjs';
import { Channel } from './channel.cjs';
import { Encoder } from './encoder.cjs';
import '../dispose-types.cjs';
import './emitter.cjs';
import '../log/log.cjs';
import '../global.cjs';

interface MessageAction {
    name: string;
    id: string;
    args?: Json[];
}
interface MessageResult {
    id: string;
    result?: Json;
    error?: {
        stack?: string;
        name: string;
        message: string;
    };
}
type Message = MessageAction | MessageResult;
interface MessagesOptions {
    timeout?: number;
}
interface MessagesDefaultMethods<L> {
    dispose: () => void;
    connect?: (channel: Channel) => void;
    options: (opt: MessagesOptions) => L;
}
type MessagesMethods<L> = L & MessagesDefaultMethods<L>;
type MessageDefinitions = Record<any, (...args: any) => Promise<any>>;
interface MessageHub {
    dispose: () => void;
    connect: (newChannel: Channel) => void;
    listen: <L extends MessageDefinitions>(newHandlers: L) => void;
    send: <L extends MessageDefinitions>() => MessagesMethods<L>;
}
declare function createPromiseProxy<P extends object>(fn: (name: string, args: any[], opt: any) => Promise<unknown>, opt: MessagesOptions, predefinedMethods?: any): P;
/**
 * RPC
 *
 * Features:
 * - Waits for connection
 * - Retries after fail
 * - Timeouts
 */
declare function useMessageHub(opt?: {
    name?: string;
    channel?: Channel;
    encoder?: Encoder;
    retryAfter?: number;
    ignoreUnhandled?: boolean;
    debug?: boolean;
    logLevel?: LogLevelAliasType;
}): MessageHub;

export { type Message, type MessageAction, type MessageDefinitions, type MessageHub, type MessageResult, type MessagesDefaultMethods, type MessagesMethods, type MessagesOptions, createPromiseProxy, useMessageHub };
