import { Encoder } from './encoder.cjs';
import { DisposerFunction } from '../dispose-types.cjs';
import { ListenerSignature, DefaultListener, Emitter, EmitterSubscriberOptions } from './emitter.cjs';
import { Channel } from './channel.cjs';
import '../global.cjs';
import '../log/log.cjs';
import '../log/log-base.cjs';

interface PubSubConfig {
    channel: Channel;
    encoder?: Encoder;
    name?: string;
    debug?: boolean;
}
declare class PubSub<L extends ListenerSignature<L> = DefaultListener> extends Emitter<L> {
    name: string;
    channel: Channel;
    encoder: Encoder;
    log: any;
    debug: boolean;
    get shortId(): string;
    constructor(opt: PubSubConfig);
    private emitSuper;
    emit<U extends keyof L>(event: U, ...args: Parameters<L[U]>): Promise<boolean>;
    publish: <U extends keyof L>(event: U, ...args: Parameters<L[U]>) => Promise<boolean>;
    subscribe: <U extends keyof L>(event: U, fn: L[U], opt?: EmitterSubscriberOptions) => DisposerFunction;
}
declare function usePubSub<L extends ListenerSignature<L> = DefaultListener>(opt: PubSubConfig): PubSub<L>;

export { PubSub, usePubSub };
