import {
  filesAsync,
  getFingerprintAsync,
  getStatAsync
} from "../chunk-Q5CKRHI6.js";
import "../chunk-EGXUCKU4.js";
import "../chunk-72CYVQ2Y.js";
import "../chunk-HMRSQHLY.js";
import "../chunk-UMUHNSGZ.js";
import "../chunk-SRT6T6F5.js";
import "../chunk-AWQDSHQ6.js";
import "../chunk-MO24G7VK.js";
import "../chunk-2PE4OYYB.js";
import "../chunk-RNL46FQ3.js";
import "../chunk-MWUFUBY5.js";
import "../chunk-GKKLBSFA.js";
import "../chunk-264HKVNG.js";
import "../chunk-BJGZAXQX.js";
import "../chunk-YKE4UGGF.js";
import "../chunk-FLFB2K34.js";
import "../chunk-HST4VI64.js";
import "../chunk-7CAGRWCE.js";
import "../chunk-A7SUGWC3.js";
import "../chunk-PXMCFDHI.js";
import "../chunk-FG5BB5ND.js";
import "../chunk-EW6FHLFK.js";
import "../chunk-MPAXUMZ5.js";
import "../chunk-MOF5RUYR.js";
import "../chunk-Y24KGDZP.js";
import "../chunk-7OAUULYN.js";
import "../chunk-NZVHNXYU.js";
import "../chunk-IQFZHKL7.js";
import "../chunk-GJGVFPRX.js";
import "../chunk-AJ3WFXQE.js";
import "../chunk-3KZ4JGBB.js";
import "../chunk-WO2K74GK.js";
import "../chunk-PJDBG5VS.js";
import "../chunk-H3BEMJTD.js";
import "../chunk-ULLOUKBT.js";
import "../chunk-KGD7JR27.js";
import "../chunk-7GOLOL5D.js";
import "../chunk-CQWFE2OA.js";
import "../chunk-VAS3X5GJ.js";
import "../chunk-GAKRSKPV.js";
import "../chunk-455C43FU.js";
import "../chunk-CFICINSP.js";
import "../chunk-RG6OSZW5.js";
import "../chunk-I45WP5PM.js";
import "../chunk-GUPXJFTH.js";
import "../chunk-WXJDMWFH.js";
import "../chunk-NJF7RWE7.js";
import "../chunk-UHTVWILC.js";
import "../chunk-T7PU5CTZ.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-AFUVZLZZ.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-QKQXPWN7.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-BCFBEP5B.js";
import "../chunk-EOHXRMVQ.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-66LHCCNT.js";
import "../chunk-4XPO57AQ.js";
import "../chunk-ACZDEHYB.js";
import "../chunk-FSDCRQB3.js";
import "../chunk-YEEGQOIW.js";
import "../chunk-AEBHR4XF.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-GY34N3KU.js";
import "../chunk-NS4INNCL.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-R6KULE2F.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-VVNSHVPQ.js";
import "../chunk-6GHO7LQW.js";

// src/node/files-async.spec.ts
describe("getStatAsync", () => {
  it("should return the stat object for a valid path", async () => {
    const path = __filename;
    const statObject = await getStatAsync(path);
    expect(statObject).toBeDefined();
    expect(statObject.isFile()).toBe(true);
  });
  it("should return undefined for an invalid path", async () => {
    const path = "/invalid/path";
    const statObject = await getStatAsync(path);
    expect(statObject).toBeUndefined();
  });
  it("should return the fingerprint for a valid path", async () => {
    const path = __filename;
    const fingerprint = await getFingerprintAsync(path);
    expect(fingerprint).toBeDefined();
    expect(typeof fingerprint).toBe("string");
  });
  it("should return undefined for an invalid path 2", async () => {
    const path = "/invalid/path";
    const fingerprint = await getFingerprintAsync(path);
    expect(fingerprint).toBeUndefined();
  });
  it("should return an array of file paths", async () => {
    const paths = await filesAsync({ basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
  });
  it("should return an array of file paths matching the pattern", async () => {
    const pattern = "*.ts";
    const paths = await filesAsync({ basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.endsWith(".ts"))).toBe(true);
  });
  it("should return an empty array if no files match the pattern", async () => {
    const pattern = "*.docx";
    const paths = await filesAsync({ basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should return an array of file paths filtered by the custom filter function", async () => {
    const filter = (name) => name.includes("spec");
    const paths = await filesAsync({ basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.includes("spec"))).toBe(true);
  });
  it("should return an empty array if no files pass the custom filter function", async () => {
    const filter = (name) => name.includes("xyz");
    const paths = await filesAsync({ basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should ignore hidden files by default", async () => {
    const paths = await filesAsync({ basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.every((path) => !path.includes("/."))).toBe(true);
  });
});
//# sourceMappingURL=files-async.spec.js.map